summaryrefslogtreecommitdiff
path: root/tests/use_case/noise_reduction/RNNNoiseUCTests.cc
diff options
context:
space:
mode:
authorRichard Burton <richard.burton@arm.com>2021-12-07 14:04:44 +0000
committerRichard <richard.burton@arm.com>2021-12-07 14:06:03 +0000
commit033c9150523387aca88dd4c89a4d5ca105d4de4e (patch)
treed37ffe4129b655f372449a6d05caec68d7e9f10b /tests/use_case/noise_reduction/RNNNoiseUCTests.cc
parent3acaaeeba7d8e85a20273bd1d8d4d9b3bb1322ad (diff)
downloadml-embedded-evaluation-kit-033c9150523387aca88dd4c89a4d5ca105d4de4e.tar.gz
MLECO-2723: Updating RNNoise to use 512 frame size
* CMSIS-DSP acceleration will now be used for FFT in RNNoise pre-processing * PESQ scores tested and similar Signed-off-by: Richard Burton <richard.burton@arm.com> Change-Id: Ifeebc041f58867909b27c948950e08f8f39ef276
Diffstat (limited to 'tests/use_case/noise_reduction/RNNNoiseUCTests.cc')
-rw-r--r--tests/use_case/noise_reduction/RNNNoiseUCTests.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/use_case/noise_reduction/RNNNoiseUCTests.cc b/tests/use_case/noise_reduction/RNNNoiseUCTests.cc
index d57fced..c2b7ffb 100644
--- a/tests/use_case/noise_reduction/RNNNoiseUCTests.cc
+++ b/tests/use_case/noise_reduction/RNNNoiseUCTests.cc
@@ -23,7 +23,7 @@
#include <catch.hpp>
#include <hal.h>
#include <Profiler.hpp>
-#include <iostream>
+
#define PLATFORM \
hal_platform platform; \
data_acq_module data_acq; \
@@ -177,8 +177,8 @@ void testInfByIndex(std::vector<uint32_t>& numberOfInferences) {
std::vector<int16_t> runtime(g_FrameLength);
std::memcpy(runtime.data(), &memDump[startOfLastInfOut], oneInferenceOutSizeBytes);
- /* Margin of 22 is 0.03% error. */
- REQUIRE_THAT(golden, Catch::Matchers::Approx(runtime).margin(22));
+ /* Margin of 43 is 0.07% error. */
+ REQUIRE_THAT(golden, Catch::Matchers::Approx(runtime).margin(43));
}
++infIndex;
}